@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004 Jorn Baayen <jorn@nl.linux.org>
+ * Copyright (C) 2004 Jorn Baayen <jbaayen@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,24 +20,29 @@
 using System;
 using System.Runtime.InteropServices;
 
-public class ColoredCellRendererPixbuf : Gtk.CellRenderer 
+namespace Muine
 {
-	~ColoredCellRendererPixbuf ()
+	public class ColoredCellRendererPixbuf : Gtk.CellRenderer 
 	{
-		Dispose ();
-	}
+		// Constructor
+		[DllImport ("libmuine")]
+		private static extern IntPtr rb_cell_renderer_pixbuf_new ();
 
-	[DllImport ("libmuine")]
-	static extern IntPtr rb_cell_renderer_pixbuf_new ();
+		public ColoredCellRendererPixbuf () : base (IntPtr.Zero)
+		{
+			base.Raw = rb_cell_renderer_pixbuf_new ();
+		}
 
-	public ColoredCellRendererPixbuf () : base (IntPtr.Zero)
-	{
-		Raw = rb_cell_renderer_pixbuf_new ();
-	}
+		// Destructor
+		~ColoredCellRendererPixbuf ()
+		{
+			Dispose ();
+		}
 
-	public Gdk.Pixbuf Pixbuf {
-		set {
-			SetProperty ("pixbuf", new GLib.Value (value));
+		// Properties
+		// Properties :: Pixbuf (set;)
+		public Gdk.Pixbuf Pixbuf {
+			set { SetProperty ("pixbuf", new GLib.Value (value)); }
 		}
 	}
 }
